function HR_DAD;
%Starts High-Rise Database-Assisted Design 1.1 program.
%Establishes all global variables, opens all ten pages and initializes all variables.

clear all;
close all;

global  textA  axesA_text  textB  axesB_text  input_coords  pos_on  pos_off  fig  sets  acc_points 
% 1. Building Information
global  Nfloors   Fdofs  Ndofs   RNmodes  AnL_A  AnL_B  anal  H_bldg
global  T  T_str  D  D_str  flnMode_shape  evectors  omega  h  
% 2. Wind Tunnel Information
global  flnFl  Vm  freq  ms  Npoints  Nstart
% 3. Program Inputs
global  flnMem  flnDif  flnProps  mem_list  props  WS  WS_str  WD  WD_str
global  MRIBij  MRIBij_str  MRIDrAc  MRIDrAc_str  mri  IMdir_A  IMdir_B  intmeth  mem_out
% 4. Loads and Reactions
global  flnMass  DL  SDL  LL  g
global  flnDLr  flnSDLr  flnLLr  frames_DL  frames_SDL  frames_LL 
global  DLf  SDLf  LLf  WLf
% 5. Wind Effect Selection
global  Qss  Hmp  Hfile  flHfile  Vth  Npointsout
global  Qs flnInDr flnAcc 
% 6. Calculations
global  flnSaveRsBij  flnSaveRsInDr  flnSaveRsAcc  flnSaveBijMRI  flnSaveInDrMRI  flnSaveAccMRI
% 7. Calculations MRI's
global  AnGld  flnDisp  wsD  wsD_str  wdD  wdD_str  flnSaveDTh   
global  AnGla  flnAccT  wsA  wsA_str  wdA  wdA_str  flnSaveATh 
% 8. Save/Load Data
global  fnSAVE  flSAVE  flnSAVE  fnLOAD  flLOAD  flnLOAD

axesA_text = ['This software computes the maximum local and global wind effects of interest '...
   'for a high-rise '...
   'buildings as a function of Mean-Recurrence Intervals (MRIs).' char(10) char(10) 'The main '...
   'menu to the left proceeds through the gathering of required information: (1) Building '...
   'Information includes basic inputs, dynamic properties and loads for analysis; (2) Wind '...
   'Tunnel Information includes model scale information and floor load time '...
   'histories; (3) Program Inputs includes member/frame information, wind speed and '...
   'direction values, and interpolation method for direction; (4) Loads & Reactions includes'...
   'the mass matrix, the static load reactions (calculated in a seperate analysis) and '...
   'load and peak factors for dynamic model; (5) Global Wind Effect Selection includes the '... 
   'inter-story '...
   'drift and top floor accelerations of interest, the wind speed database and the points '...
   'considered in the time histories (sampling rate); (6) Calculations includes the local and global '...
   'response surfaces (RS) and the mean recurrence intervals of the wind effects; (7) Additional '...
   'Output allows for the possibility to save time histories of displacements and top floor '...   
   'accelerations for selected wind speeds and directions; and (8) Save/'... 
   'Load Data provides the option to save the current input data set or load a presaved set.'];
axesB_text = ['Be sure to proceed through the whole menu or else the default values '...
   'will be used!' char(10) char(10) 'You may click on any '...
   'menu item at any time to either view the respective information or change them. The '...
   'purple information icons [?] provide the variable name, variable size and a '...
   'description about the particular parameter(s).' char(10) char(10) 'You may return to '...
   'this page at any time using the ''Main Menu'' button at the bottom without losing any '...
   'changed information, or you can simply navigate through the menu in any order.'...
    char(10) char(10) 'You can return to the very first page by hitting the ''Go Back'' '...
   'button from this page only.'];
sets        = [];                         % Number of column lines where the interstory is to be controlled 
acc_points  = [];                         % Number of points where the top floor acceleration is to be controlled 

%%%%%%%%%%%%%%%%    Page_One.fig    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
H_bldg  = [];                             % Building height
Nfloors = [];                             % Number of stories 
Fdofs   = [];                             % No. dynamic degrees of freedom (d.o.f.) per floor
Ndofs   = Nfloors*Fdofs;                  % Total no. of d.o.f. 
RNmodes = [];                             % Number of eigenmodes of vibration considered
T_str   = '';                             % Modal period values (sec) - string
T       = str2num(T_str);                 % Modal period values (sec) - numeric
T_all   = diag(T);                        % Modal period matrix (diagonal)
f       = inv(T_all);                     % Modal frequency matrix (diagonal)
omega   = 2*pi*f;                         % Natural circular frequencies matrix (diagonal)
D_str   = '';                             % Modal damping ratios (%) - string
D       = str2num(D_str);                 % Modal damping ratios (%) - numeric
D_all   = D/100;                          % Convert percentage to decimal
h       = diag(D_all);                    % Modal damping matrix (diagonal)
flnMode_shape = '';                       % Mode Shape, contains variable 'evectors'
AnL_A   = 1;                              % Analysis Loads A: applied & inertial (default)
AnL_B   = 0;                              % Analysis Loads B: applied only
anal    = 'A';                            % Default for 'Loads for Analysis' = A
Page_One;
movegui(Page_One,'center')

%%%%%%%%%%%%%%%%    Page_Two.fig    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
flnFl   = '';                             % File location, contains variable 'flnFl'               
Vm      = [];                             % Wind speed @ model roof (m/s, mean hourly)
freq    = [];                             % Model scale sampling rate (Hz)
ms      = [];                             % Model scale (ms:1)
Npoints = [];                             % No. of sample points per floor load
Nstart  = [];                             % No. of initial points eliminated per time history of floor load 
Page_Two;
movegui(Page_Two,'center')

%%%%%%%%%%%%%%    Page_Three.fig    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
flnMem        = '';                       % File location\name, contains variable 'mem_list'
mem           = [];                       % Current member number in analysis, from mem_list
mem_out       = [];                       % Member number for output, from mem_list
flnDif        = '';                       % File location\name, contains variable dif
flnProps      = '';                       % File location\name, contains variable 'props'
WS_str        = '';                       % Wind speeds (m/s) - string
WS            = str2num(WS_str);          % Wind speeds (m/s) - numeric
WD_str        = '';                       % Wind directions (degrees) - string
WD            = str2num(WD_str);          % Wind directions (degrees) - numeric
MRIBij_str    = '';                       % Mean recurrence intervals local response (yr) - string      
MRIBij        = str2num(MRIBij_str);      % Mean recurrence intervals local response(yr) - numeric
MRIDrAc_str   = '';                       % Mean recurrence intervals global response(yr) - string 
MRIDrAc       = str2num(MRIDrAc_str);     % Mean recurrence intervals global response(yr) - numeric
mri           = [];                       % Specific MRI for output
IMdir_A       = 0;                        % Interpolation Method A: between WS and WD
IMdir_B       = 1;                        % Interpolation Method B: between WS, larger WD (default)
intmeth       = 'B';                      % Default for 'Interpolation Method' = B
Page_Three;
movegui(Page_Three,'center')

%%%%%%%%%%%%%%%    Page_Four.fig    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
flnMass = '';                             % File location\name, contains variable 'mass'
flnDLr  = '';                             % File location\name, contains variable 'frames_DL'
flnSDLr = '';                             % File location\name, contains variable 'frames_SDL'
flnLLr  = '';                             % File location\name, contains variable 'frames_LL'
DLf     = [];                             % Load factor - Dead load (DL)
SDLf    = [];                             % Load factor - Superimposed Dead load (SDL)
LLf     = [];                             % Load factor - Live load (LL)
WLf     = [];                             % Load factor - Wind load (WL)
g       = [];                             % Peak factor for the calculation of the local member response 
Page_Four;
movegui(Page_Four,'center')

%%%%%%%%%%%%%%%    Page_Five.fig    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Qss     = 0;                              % Wind load effect of interest
Hmp     = [];                             % Hurricane milepost corresponding to NIST database
Hfile   = [];                             % Associated hurricane file no. for database lookup
Vth     = [];                             % Minimum threshold of wind speeds (database lookup)
Qs      = 0;                              % Calculate estimated peaks (default)
flnInDr = '';
flnAcc  = '';
Page_Five;
movegui(Page_Five,'center')

%%%%%%%%%%%%%%%%    Page_Six.fig    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
flnSaveRsBij                  = '';       % Save time history for each (WS,WD) combination (default)
flnSaveRsInDr                 = '';       % File location\name, for saveBij
flnSaveRsAcc                  = '';       % File location\name, wind effect peaks per (WS,WD)
flnSaveBijMRI                 = ''; 
flnSaveInDrMRI                = '';       % File location\name, mean recurrence intervals
flnSaveAccMRI                 = ''; 
Page_Six;
movegui(Page_Six,'center')

%%%%%%%%%%%%%%%%    Page_Seven.fig    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
AnGld                         = 0;
flnDisp                       = ''; 
wsD_str                       = '';
wsD                           = str2num(wsD_str);
wdD_str                       = '';
wdD                           = str2num(wdD_str);
flnSaveDTh                    = '';      
AnGla                         = 0;
flnAccT                       = '';  
wsA_str                       = '';
wsA                           = str2num(wsA_str);
wdA_str                       = '';  
wdA                           = str2num(wdA_str); 
flnSaveATh                    = '';                   
Page_Seven; 
movegui(Page_Seven,'center')

%%%%%%%%%%%%%%%%    Page_Eight.fig    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 8. Save/Load Data
flnSAVE = '';                             % File location\name, save current variables
flnLOAD = '';                             % File location\name, load saved variables
Page_Eight;
movegui(Page_Eight,'center')

%%%%%%%%%%%%%%%%   Open All Pages   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Open the first two pages last so they are on top
Page_Main
movegui(Page_Main,'center')
Page_Open
movegui(Page_Open,'center')
