function Program1;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Program1.m %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

global  textA  axesA_text  textB  axesB_text  input_coords  pos_on  pos_off  fig  sets  acc_points 
% 1. Building Information
global  Nfloors  Fdofs  Ndofs   RNmodes  AnL_A  AnL_B  anal  H_bldg
global  T  T_str  D  D_str  flnMode_shape  evectors  omega  h
% 2. Wind Tunnel Information
global  flnFl  Vm  freq  ms  Npoints  Nstart
% 3. Program Inputs
global  flnMem  flnDif  flnProps  mem_list  props  WS  WS_str  WD  WD_str
global  MRIBij  MRIBij_str  MRIDrAc  MRIDrAc_str  mri  IMdir_A  IMdir_B  intmeth  mem_out
% 4. Loads and Reactions
global  flnMass  DL  SDL  LL  g
global  flnDLr  flnSDLr  flnLLr  frames_DL  frames_SDL  frames_LL
global  DLf  SDLf  LLf  WLf
% 5. Wind Effect Selection
global  Qss  Hmp  Hfile  Vth  Npointsout
global  Qs  flHfile flnInDr flnAcc
% 6. Calculations
global  flnSaveRsBij  flnSaveRsInDr  flnSaveRsAcc  flnSaveBijMRI  flnSaveInDrMRI  flnSaveAccMRI
% 7. Output
global  AnGld  flnDisp  wsD  wsD_str  wdD  wdD_str  flnSaveDTh   
global  AnGla  flnAccT  wsA  wsA_str  wdA  wdA_str  flnSaveATh 
% 8. Save/Load Data
global  fnSAVE  flSAVE  flnSAVE  fnLOAD  flLOAD  flnLOAD

%
%%%%%%%%%%%%%%%%%%%%%%%% Member list : mem_list, Page 3, [1 x any] %%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load 'flnMem' and check for errors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear fid; fid=fopen(flnMem);
if fid == -1
    errordlg('Unable to open ''flnMem'' - Page 3')
    error   ('Unable to open ''flnMem'' - Page 3')
end
fclose(fid); clear fid;
mem_list=[]; load (flnMem)
if isempty(mem_list)==1
    errordlg('Variable ''mem_list'' not defined. See flnMem on Page 3')
    error   ('Variable ''mem_list'' not defined. See flnMem on Page 3')
end
if min(size(mem_list,1)) ~= 2
    errordlg('Variable ''mem_list'' should be a 2 x number of members')
    error   ('Variable ''mem_list'' should be a 2 x number of members')
end
%%%%%%%%%%%%%%%%%% Member properties : props, Page 3, [members x 5] %%%%%%%%%%%%%%%%%
% Load 'flnProps' and check for errors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear fid; fid=fopen(flnProps);
if fid == -1
    errordlg('Unable to open ''flnProps'' - Page 3')
    error   ('Unable to open ''flnProps'' - Page 3')
end
fclose(fid); clear fid;
props=[]; load(flnProps)
if isempty(props)==1
    errordlg('Variable ''props'' not defined. See flnProps on Page 3')
    error   ('Variable ''props'' not defined. See flnProps on Page 3')
end
if size(props,1) ~= length(mem_list(1,:)) | size(props,2) ~= 5
    errordlg('Variable ''props'' not properly sized members x 5)')
    error   ('Variable ''props'' not properly sized members x 5)')
end
all_mems = props(:,1);      % Assign internal variables to values in 'props'
Pnt          = props(:,2);
Pnc          = props(:,3);   
Mn2          = props(:,4);
Mn3          = props(:,5);
%%%%%%%%%%%% Static load reactions - DL : frames_DL, Page 4, [members x 10] %%%%%%%%%%
% Load 'flnDLr' and check for errors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear fid; fid=fopen(flnDLr);
if fid == -1
    errordlg('Unable to open ''flnDLr'' - Page 4')
    error   ('Unable to open ''flnDLr'' - Page 4')
end
fclose(fid); clear fid;
frames_DL=[]; load (flnDLr)
if isempty(frames_DL)==1
    errordlg('Variable ''frames_DL'' not defined. See flnDLr on Page 4')
    error   ('Variable ''frames_DL'' not defined. See flnDLr on Page 4')
end
if size(frames_DL,1) ~= length(mem_list(1,:)) | size(frames_DL,2) ~= 10
    errordlg('Variable ''frames_DL'' not properly sized members x 10)')
    error   ('Variable ''frames_DL'' not properly sized (members x 10)')
end
% Assign internal variables to values of 'frames_DL'
% (units: N/N*m or kN/kN*m; choice should be consistent with the units used in function 'F_Ft.m')
P_DL         = frames_DL(:,[2 5 8]);
M2_DL        = frames_DL(:,[3 6 9]);
M3_DL        = frames_DL(:,[4 7 10]);
%%%%%%%%%%% Static load reactions - SDL : frames_SDL, Page 4, [members x 10] %%%%%%%%%
% Load 'flnSDLr' and check for errors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear fid; fid=fopen(flnSDLr);
if fid == -1
    errordlg('Unable to open ''flnSDLr'' - Page 4')
    error   ('Unable to open ''flnSDLr'' - Page 4')
end
fclose(fid); clear fid;
frames_SDL=[]; load (flnSDLr)
if isempty(frames_SDL)==1
    errordlg('Variable ''frames_SDL'' not defined. See flnSDLr on Page 4')
    error   ('Variable ''frames_SDL'' not defined. See flnSDLr on Page 4')
end
if size(frames_SDL,1) ~= length(mem_list(1,:)) | size(frames_SDL,2) ~= 10
    errordlg('Variable ''frames_SDL'' not properly sized members x 10)')
    error   ('Variable ''frames_SDL'' not properly sized members x 10')
end
% Assign internal variables to values of 'frames_SDL'
% (units: N/N*m or kN/kN*m; choice should be consistent with the units used in function 'F_Ft.m')
P_SDL        = frames_SDL(:,[2 5 8]);
M2_SDL       = frames_SDL(:,[3 6 9]);
M3_SDL       = frames_SDL(:,[4 7 10]);
%%%%%%%%%%%% Static load reactions - LL : frames_LL, Page 4, [members x 10] %%%%%%%%%%
% Load 'flnLLr' and check for errors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear fid; fid=fopen(flnLLr);
if fid == -1
    errordlg('Unable to open ''flnLLr'' - Page 4')
    error   ('Unable to open ''flnLLr'' - Page 4')
end
fclose(fid); clear fid;
frames_LL=[]; load (flnLLr)
if isempty(frames_LL)==1
    errordlg('Variable ''frames_LL'' not defined. See flnLLr on Page 4')
    error   ('Variable ''frames_LL'' not defined. See flnLLr on Page 4')
end
if size(frames_LL,1) ~= length(mem_list(1,:)) | size(frames_LL,2) ~= 10
    errordlg('Variable ''frames_LL'' not properly sized (members x 10)')
    error   ('Variable ''frames_LL'' not properly sized (members x 10)')
end
% Assign internal variables to values of 'frames_LL'
% (units: N/N*m or kN/kN*m; choice should be consistent with the units used in function 'F_Ft.m')
P_LL         = frames_LL(:,[2 5 8]);
M2_LL        = frames_LL(:,[3 6 9]);
M3_LL        = frames_LL(:,[4 7 10]);
%%%%%%%%%%%% Load factors for dynamic model : DLf, SDLf, LLf, WLf, Page 4, [1 x 1] %%%%%%%%%%%
% Reassign load factor variables to internal variables
DL_fact      = DLf;
SDL_fact     = SDLf;
LL_fact      = LLf;
WL_fact      = WLf;
%%%%%%%%%%%%% Interstory Drift location : interstory_location, Page 5, [any x 3] %%%%%%%%%%%%%
% Load 'flnInDr' and check for errors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear fid; fid=fopen(flnInDr);
if fid == -1
    errordlg('Unable to open ''flnInDr'' - Page 5')
    error   ('Unable to open ''flnInDr'' - Page 5')
end
fclose(fid); clear fid;
interstory_location=[]; load (flnInDr)
if isempty(interstory_location)==1
    errordlg('Variable ''interstory_location'' not defined. See flnInDr on Page 5')
    error   ('Variable ''interstory_location'' not defined. See flnInDr on Page 5')
end
if min(size(interstory_location,2)) ~= 3
    errordlg('Variable ''interstory_location'' should be any x 3')
    error   ('Variable ''interstory_location'' should be any x 3')
end
%%%%%%%%%%%%%% Acceleration location : acceleration_location, Page 5, [any x 2] %%%%%%%%%%%%%%
% Load 'flnAcc' and check for errors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear fid; fid=fopen(flnAcc);
if fid == -1
    errordlg('Unable to open ''flnAcc'' - Page 5')
    error   ('Unable to open ''flnAcc'' - Page 5')
end
fclose(fid); clear fid;
acceleration_location=[]; load (flnAcc)
if isempty(acceleration_location)==1
    errordlg('Variable ''acceleration_location'' not defined. See flnAcc on Page 5')
    error   ('Variable ''acceleration_location'' not defined. See flnAcc on Page 5')
end
if min(size(acceleration_location,2)) ~= 2
    errordlg('Variable ''acceleration_location'' should be any x 2')
    error   ('Variable ''acceleration_location'' should be any x 2')
end
if AnGld == 1
    %%%%%%%%%%%%% Displacement location : displacement_location, Page 7, [any x 2] %%%%%%%%%%%%%
    % Load 'flnDisp' and check for errors
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    clear fid; fid=fopen(flnDisp);
    if fid == -1
        errordlg('Unable to open ''flnDisp'' - Page 7')
        error   ('Unable to open ''flnDisp'' - Page 7')
    end
    fclose(fid); clear fid;
    displacement_location=[]; load (flnDisp)
    if isempty(displacement_location)==1
        errordlg('Variable ''displacement_location'' not defined. See flnDisp on Page 7')
        error   ('Variable ''displacement_location'' not defined. See flnDisp on Page 7')
    end
    if min(size(displacement_location,2)) ~= 2
        errordlg('Variable ''displacement_location'' should be any x 2')
        error   ('Variable ''displacement_location'' should be any x 2')
    end
end
if AnGla == 1
    %%%%%%%%%%%%%% Acceleration location for time history output: acc_location, Page 7, [any x 2] 
    % Load 'flnAccT' and check for errors
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    clear fid; fid=fopen(flnAccT);
    if fid == -1
        errordlg('Unable to open ''flnAccT'' - Page 7')
        error   ('Unable to open ''flnAccT'' - Page 7')
    end
    fclose(fid); clear fid;
    acc_location=[]; load (flnAccT)
    if isempty(acc_location)==1
        errordlg('Variable ''acc_location'' not defined. See flnAccT on Page 7')
        error   ('Variable ''acc_location'' not defined. See flnAccT on Page 7')
    end
    if min(size(acc_location,2)) ~= 2
        errordlg('Variable ''acc_location'' should be any x 2')
        error   ('Variable ''acc_location'' should be any x 2')
    end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Run a loop to calculate variables M and Fai on if inertial loads are to be included %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if AnL_A == 1
    %%%%%%%%%%%%%%%%%%%%%%%%%% Mass matrix : mass, Page 4, [1 x Ndofs] %%%%%%%%%%%%%%%%%%%%%%%%%
    % Load 'flnMass' and check for errors
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    clear fid; fid=fopen(flnMass);
    if fid == -1
        errordlg('Unable to open ''flnMass'' - Page 4')
        error   ('Unable to open ''flnMass'' - Page 4')
    end
    fclose(fid); clear fid;
    mass=[]; load (flnMass);        
    % Variable mass is a vector [m_x1, m_y1, m_rz1, m_x2, m_y2, m_rz2 ... ] of length Ndofs
    if isempty(mass)==1
        errordlg('Variable ''mass'' not defined. See flnMass on Page 4')
        error   ('Variable ''mass'' not defined. See flnMass on Page 4')
    end
    if length(mass) ~= Ndofs
        errordlg('Variable ''mass'' not properly sized (vector with length =Ndofs)')
        error   ('Variable ''mass'' not properly sized (vector with length =Ndofs)')
    end
    if min(mass)<1
        errordlg('All ''mass'' entries must be positive)')
        error   ('All ''mass'' entries must be positive')
    end
    % Convert the saved mass vector to a mass matrix
    mx          = mass(1:Fdofs:Fdofs*Nfloors)';
    my          = mass(2:Fdofs:Fdofs*Nfloors)';
    mrz         = mass(3:Fdofs:Fdofs*Nfloors)';
    m           = cat(2, mx, my, mrz);
    M           = diag(m);
    % THE MASS MATRIX:  diag[m_1x, m_2x, m_3x ... m_1y, m_2y, m_3y ... m_1rz, m_2rz, m_3rz ...],
    % where in m_ij i = floor # and j = d.o.f.
    %%%%%%%%%%%%%%%%%%% Modal matrix : evectors, Page 1, [Ndofs x RNmodes] %%%%%%%%%%%%%%%%%%%%%%%
    % Load 'flnMode_shape' and check for errors
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
    clear fid; fid=fopen(flnMode_shape);
    if fid == -1
        errordlg('Unable to open ''flnMode_shape'' - Page 1')
        error   ('Unable to open ''flnMode_shape'' - Page 1')
    end
    fclose(fid); clear fid;
    evectors=[]; load (flnMode_shape)
    if isempty(evectors) == 1
        errordlg('Variable ''evectors'' not defined. See flnMode_shape on Page 1')
        error   ('Variable ''evectors'' not defined. See flnMode_shape on Page 1')
    end
    if size(evectors,1) ~= Ndofs 
        errordlg('Variable ''evectors'' not properly sized (Ndofs x RNmodes)')
        error   ('Variable ''evectors'' not properly sized (Ndofs x RNmodes)')
    end
    Fai      = evectors; % Assign internal variable to 'evectors'
    faix     = Fai(1:(Ndofs/Fdofs),1:RNmodes);                               % Assign internal variable for d.o.f. 1
    if RNmodes > 1
    faiy     = Fai((Ndofs/Fdofs)+1:(Fdofs-1)*(Ndofs/Fdofs),1:RNmodes);       % Assign internal variable for d.o.f. 2
    end
    if RNmodes > 2
    fairz    = Fai((Fdofs-1)*(Ndofs/Fdofs)+1:Ndofs,1:RNmodes);               % Assign internal variable for d.o.f. 3
    end
end    % loop back on AnL

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% WIND EFFECT CALCULATION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%% Dynamic influence coefficients : dif, Page 3, [ 3*Ndofs x 6 x members ]%%%%%%%%
% NOTE: The dif's are dimensionless
% Load flnDif and check for errors
clear fid; fid=fopen(flnDif);
if fid == -1
    errordlg(['Unable to open ''flnDif  dif_all'' - Page 3'])
    error   (['Unable to open ''flnDif  dif_all'' - Page 3'])
end
fclose(fid); clear fid;
clear dif
dif=[]; load (flnDif) 
if isempty(dif)==1
    errordlg(['Variable ''dif'' not defined for dif_all''. '...
        'See flnDif on Page 3'])
    error   (['Variable ''dif'' not defined for dif_all''. '...
        'See flnDif on Page 3'])
end
if size(dif,1) ~= 3*Ndofs | size(dif,2) ~= 6
    errordlg(['Variable ''dif'' not properly sized (3*Ndofs x 6 x members)'])
    error   (['Variable ''dif'' not properly sized (3*Ndofs x 6 x members)'])
end
P_col_no    = 1;                           % Assign local variable, axial load
M2_col_no   = 5;                           % Assign local variable, moment M2
M3_col_no   = 6;                           % Assign local variable, moment M3

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Definition of the 3D array containing the peak demand for each member % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Bij_RS=zeros(length(WD),length(WS),length(mem_list(1,:)));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%tic
% Calculate peak wind effect of interest for each wind direction (WD) and wind speed (WS)
w = waitbar(0,'Running Program1.m   Please wait...'); c=0;
a               = 0;                            % Counting variable for WD
for ddd = 1:length(WD)
    dir         = WD(ddd);                      % Internal variable for direction (WD)
    a           = a+1;
    b           = 0;                            % Counting variable for WS
    dir_list(a) = dir;                          % Variable to store wind directions (WD) used
    Fl_th       = Load_Fl(dir,Nfloors,Npoints); %'Load_Fl' loads the floor load time series 
                                                % and stores them in a matrix Fl_th of size Ndofs x Npoints                                             
    for vvv = 1:length(WS)
        b           = b+1;
        V           = WS(vvv);                    % Reassign variable
        V_list(b)   = V;                          % Variable to store wind speeds (WS) used
        dt          = (1/freq)*(Vm/V)*(ms);       % Time increment such that (nD/V)model = (nD/V)prototype
        Fls_th      = Fl_scaled_th(Fl_th,V);      % 'Fl_scaled_th' calculates the scaled wind load matrix, Fls_th, of size
                                                  %  Ndofs x Npoints, for the dynamic MDOF system                                          
        WS_WD       = [V dir];
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % Run a loop to integrate equations of motion if inertial loads are to be included % 
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %tic
        if AnL_A == 1
            disp_x  = zeros(Nfloors,Npoints);          % Initialize variables
            disp_y  = zeros(Nfloors,Npoints);
            disp_rz = zeros(Nfloors,Npoints);
            acc_x   = zeros(Nfloors,Npoints);
            acc_y   = zeros(Nfloors,Npoints);
            acc_rz  = zeros(Nfloors,Npoints);
            % This function calculates the generalized displacements, velocities and acceleration
            [gen_d,gen_v,gen_a,Npointsout] = F_and_M_gen(M,Fai,Fls_th,dt,h,omega);
            disp_x      = faix * gen_d;               % Mass displacements, d.o.f. 1 (Nfloors x Npoints)
            %vel_x       = faix * gen_v;               % Mass velocities,    d.o.f. 1 (Nfloors x Npoints)
            acc_x       = faix * gen_a;               % Mass accelerations, d.o.f. 1 (Nfloors x Npoints)
            if RNmodes > 1
            disp_y      = faiy * gen_d;               % Mass displacements, d.o.f. 2 (Nfloors x Npoints)
            %vel_y       = faiy * gen_v;               % Mass velocities,    d.o.f. 2 (Nfloors x Npoints)
            acc_y       = faiy * gen_a;               % Mass accelerations, d.o.f. 2 (Nfloors x Npoints)
            end
            if RNmodes > 2
            disp_rz     = fairz * gen_d;              % Mass displacements, d.o.f. 3 (Nfloors x Npoints)
            %vel_rz      = fairz * gen_v;              % Mass velocities,    d.o.f. 3 (Nfloors x Npoints)
            acc_rz      = fairz * gen_a;              % Mass accelerations, d.o.f. 3 (Nfloors x Npoints)
            end
            acc=cat(1,acc_x,acc_y,acc_rz);          
            Cov_Tot_F=cov((Fls_th(:,Nstart:Npoints)-M*acc(:,Nstart:Npoints))');
            %------------------------------------------------------------------
            % SAVE TIME HISTORIES FOR CERTAIN WIND DIRECTIONS AND SPEEDS
            %------------------------------------------------------------------
            if AnGld == 1
                for i=1:length(wsD)
                    if (wsD(i) == V) & (wdD(i) == dir)
                        disp_sets=length(displacement_location)/Nfloors;
                        disp_set = 0;
                        for j=1:disp_sets
                            dx(:,1)=displacement_location(1+disp_set:Nfloors+disp_set,1);
                            dy(:,1)=displacement_location(1+disp_set:Nfloors+disp_set,2);
                            for k=1:Nfloors
                                % time histories
                                Disp(k,:,1)=(disp_x(k,:)-dy(k,1)*disp_rz(k,:));
                                Disp(k,:,2)=(disp_y(k,:)+dx(k,1)*disp_rz(k,:));
                            end
                            Disp(:,:,3)=disp_rz(:,:);                      
                            eval ([ 'disp_set_' num2str(j) '_' num2str(dir) '_' num2str(V) '(:,:,:) = Disp; ']);
                            K4 = findstr(flnSaveDTh,'.mat');
                            if ~isempty(K4)
                                flnSaveDTh = flnSaveDTh(1:K4-1);
                            end
                            save ([flnSaveDTh '_set_' num2str(j) '_' num2str(dir) '_' num2str(V)], ['disp_set_' num2str(j) '_' num2str(dir) '_' num2str(V) ] );
                        end
                    end
                end     
            end
            if AnGla == 1
                for i=1:length(wsA)
                    if (wsA(i) == V) & (wdA(i) == dir)
                        acc_point=length(acc_location);
                        for j=1:acc_point
                            acc_T(j,:,1)=(acc_x(Nfloors,:)-acc_location(j,1)*acc_rz(Nfloors,:));
                            acc_T(j,:,2)=(acc_y(Nfloors,:)+acc_location(j,2)*acc_rz(Nfloors,:));
                            acc_T(j,:,3)=acc_rz(Nfloors,:);
                        end
                        eval ([ 'Top_floor_acc_' num2str(dir) '_' num2str(V) '(:,:,:) = acc_T; ']);
                        K5 = findstr(flnSaveATh,'.mat');
                        if ~isempty(K5)
                            flnSaveATh = flnSaveATh(1:K5-1);
                        end
                        save ([flnSaveATh '_' num2str(dir) '_' num2str(V)], [ 'Top_floor_acc_' num2str(dir) '_' num2str(V)] );
                    end
                end 
            end      
        else
            Npointsout  = Npoints;                    % Assign internal variable
            Cov_Tot_F=cov(Fls_th');
        end    % loop back on AnL
        %toc
        %t_dynamic=toc
        Fls_mean=mean(Fls_th')';

        %------------------------------------------------------------------
        % INTER-STORY DRIFT and ACCELERATION
        %------------------------------------------------------------------
       
        %%%%%%%%%%%%%%%%%%%%%
        % INTER-STORY DRIFT %
        %%%%%%%%%%%%%%%%%%%%%
        
        % Eliminate the first Nstart points in order to avoid the intial signal instability 
        disp_x_s=disp_x(:,Nstart:Npoints);
        disp_y_s=disp_y(:,Nstart:Npoints);
        disp_rz_s=disp_rz(:,Nstart:Npoints);
        % -------------------------------------------------------------------------

        sets=length(interstory_location(:,1))/Nfloors;

        set=0;
        for j=1:sets

            nx(:,1)=interstory_location(1+set:Nfloors+set,1);
            ny(:,1)=interstory_location(1+set:Nfloors+set,2);
            h_s(:,1)=interstory_location(1+set:Nfloors+set,3);

            % ---------------------------------------------------------------------

            % time histories first floor 
            In_Dr_x(1,:)=(disp_x_s(1,:)-ny(1,1)*disp_rz_s(1,:))./h_s(1,1);
            In_Dr_y(1,:)=(disp_y_s(1,:)+nx(1,1)*disp_rz_s(1,:))./h_s(1,1);

            if Qss == 1 % Gamma estimated  maximums ----------------------------
                [In_Dr_x_Max,In_Dr_x_Min] = maxminest(In_Dr_x(1,:)); 
                In_Dr_x_Max_abs(1,1,1) = max(abs(In_Dr_x_Max),abs(In_Dr_x_Min));

                [In_Dr_y_Max,In_Dr_y_Min] = maxminest(In_Dr_y(1,:)); 
                In_Dr_y_Max_abs(1,1,1) = max(abs(In_Dr_y_Max),abs(In_Dr_y_Min));

            else % Observered maximums ----------------------------------------
                In_Dr_x_Max = max(In_Dr_x(1,:)); 
                In_Dr_x_Min = min(In_Dr_x(1,:));
                In_Dr_x_Max_abs(1,1,1) = max(abs(In_Dr_x_Max),abs(In_Dr_x_Min));

                In_Dr_y_Max = max(In_Dr_y(1,:)); 
                In_Dr_y_Min = min(In_Dr_y(1,:));
                In_Dr_y_Max_abs(1,1,1)=max(abs(In_Dr_y_Max),abs(In_Dr_y_Min));
            end
            %------------------------------------------------------------------

            for i=2:Nfloors

                % time histories floors 2 to N 
                In_Dr_x(1,:) = ((disp_x_s(i,:)-ny(i,1)*disp_rz_s(i,:))-(disp_x_s(i-1,:)-ny(i-1,1)*disp_rz_s(i-1,:)))./h_s(i,1);
                In_Dr_y(1,:) = ((disp_y_s(i,:)+nx(i,1)*disp_rz_s(i,:))-(disp_y_s(i-1,:)+nx(i-1,1)*disp_rz_s(i-1,:)))./h_s(i,1);

                if Qss == 1 % Gamma estimated  maximums ----------------------------
                    [In_Dr_x_Max,In_Dr_x_Min] = maxminest(In_Dr_x(1,:)); 
                    In_Dr_x_Max_abs(1,1,i) = max(abs(In_Dr_x_Max),abs(In_Dr_x_Min));

                    [In_Dr_y_Max,In_Dr_y_Min] = maxminest(In_Dr_y(1,:)); 
                    In_Dr_y_Max_abs(1,1,i) = max(abs(In_Dr_y_Max),abs(In_Dr_y_Min));

                else % Observered maximums ----------------------------------------
                    In_Dr_x_Max = max(In_Dr_x(1,:)); 
                    In_Dr_x_Min = min(In_Dr_x(1,:));
                    In_Dr_x_Max_abs(1,1,i) = max(abs(In_Dr_x_Max),abs(In_Dr_x_Min));

                    In_Dr_y_Max = max(In_Dr_y(1,:)); 
                    In_Dr_y_Min = min(In_Dr_y(1,:));
                    In_Dr_y_Max_abs(1,1,i)=max(abs(In_Dr_y_Max),abs(In_Dr_y_Min));
                end
                %------------------------------------------------------------------
            end
            InDr_RS=cat(3,In_Dr_x_Max_abs,In_Dr_y_Max_abs);
            eval ([ 'InDr_RS_set_' num2str(j) ' (a,b,:) = InDr_RS;']);
            set=set+Nfloors;
        end
      
        %%%%%%%%%%%%%%%%
        % ACCELERATION %
        %%%%%%%%%%%%%%%%
        
        % Eliminate the first Nstart points in order to avoid the intial signal instability 
        acc_x_s=acc_x(Nfloors,Nstart:Npoints);
        acc_y_s=acc_y(Nfloors,Nstart:Npoints);
        acc_rz_s=acc_rz(Nfloors,Nstart:Npoints);
        % -------------------------------------------------------------------------

        acc_points=length(acceleration_location(:,1));

        for j=1:acc_points

            anx(1,1)=acceleration_location(j,1);
            any(1,1)=acceleration_location(j,2);

            % time histories  
            top_acc_x(1,:)=(acc_x_s(1,:)-any(1,1)*acc_rz_s(1,:));
            top_acc_y(1,:)=(acc_y_s(1,:)+anx(1,1)*acc_rz_s(1,:));


            if Qs == 1 % Gamma estimated  maximums ----------------------------
                [top_acc_x_Max,top_acc_x_Min] = maxminest(top_acc_x(1,:)); 
                top_acc_x_Max_abs(1,1,1) = max(abs(top_acc_x_Max),abs(top_acc_x_Min));

                [top_acc_y_Max,top_acc_y_Min] = maxminest(top_acc_y(1,:)); 
                top_acc_y_Max_abs(1,1,1) = max(abs(top_acc_y_Max),abs(top_acc_y_Min));

            else % Observered maximums ----------------------------------------
                top_acc_x_Max = max(top_acc_x(1,:)); 
                top_acc_x_Min = min(top_acc_x(1,:));
                top_acc_x_Max_abs(1,1,1) = max(abs(top_acc_x_Max),abs(top_acc_x_Min));

                top_acc_y_Max = max(top_acc_y(1,:)); 
                top_acc_y_Min = min(top_acc_y(1,:));
                top_acc_y_Max_abs(1,1,1)=max(abs(top_acc_y_Max),abs(top_acc_y_Min));
            end
            Acc_RS=cat(3,top_acc_x_Max_abs,top_acc_y_Max_abs);
            eval ([ 'Acc_RS_point_' num2str(j) ' (a,b,:) = Acc_RS;']);

        end
        
        %------------------------------------------------------------------
        
        %%%%%%%%%%%%%%%%%%
        % MEMBER EFFECTS %
        %%%%%%%%%%%%%%%%%%
       
        %tic
        for q=1:length(mem_list(1,:))

            Bij_peak_3sec                = [];  % Initialize variables
            Bij_peak_1                   = [];  % Initialize variables
            Bij_peak_2                   = [];  % Initialize variables
            
            str1=mem_list(2,q);
            
            if strncmp(str1, 'B', 1) | strncmp(str1, 'O', 1)
                gamma=1;
                alfa=1;
                beta=3;
            elseif strncmp(str1, 'C', 1)
                gamma=1;
                alfa=2;
                beta=3;
            else
                gamma=2;
                alfa=2;
                beta=2;
            end
                          
            for axpos_index = gamma:alfa:beta % Axial position on member
                
                count=[0 Ndofs 2*Ndofs 3*Ndofs];
                
                C_NN    = 0; % Initialize variables
                C_NM2   = 0;
                C_NM3   = 0;
                C_M2M3  = 0;
                C_M2M2  = 0;
                C_M3M3  = 0;
                
                if gamma == 2
                    
                    C_NN    = dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(1:Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q))+...
                              2*dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(1:Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q))+...
                              2*dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(1:Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q))+...
                              2*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q));
                else
                    
                    C_NN    = dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(1:Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q))+...
                              2*dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(1:Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q))+...
                              2*dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(1:Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q))+...
                              2*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q));
                   
                    C_M2M2  = dif(1+count(axpos_index):Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(1:Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),M2_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M2_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M2_col_no,q))+...
                              2*dif(1+count(axpos_index):Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(1:Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M2_col_no,q))+...
                              2*dif(1+count(axpos_index):Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(1:Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M2_col_no,q))+...
                              2*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M2_col_no,q));          

                    C_M3M3  = dif(1+count(axpos_index):Nfloors+count(axpos_index),M3_col_no,q)'*(Cov_Tot_F(1:Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M3_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M3_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M3_col_no,q))+...
                              2*dif(1+count(axpos_index):Nfloors+count(axpos_index),M3_col_no,q)'*(Cov_Tot_F(1:Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M3_col_no,q))+...
                              2*dif(1+count(axpos_index):Nfloors+count(axpos_index),M3_col_no,q)'*(Cov_Tot_F(1:Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M3_col_no,q))+...
                              2*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M3_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M3_col_no,q));            

                    C_NM2   = dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(1:Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),M2_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M2_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M2_col_no,q))+...
                              dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(1:Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M2_col_no,q))+...
                              dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(1:Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M2_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),M2_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M2_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),M2_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M2_col_no,q));

                    C_NM3   = dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(1:Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(1:Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(1+count(axpos_index):Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(1:Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),P_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M3_col_no,q));

                    C_M2M3  = dif(1+count(axpos_index):Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(1:Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(1+count(axpos_index):Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(1:Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(1+count(axpos_index):Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(1:Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(Nfloors+1:2*Nfloors,2*Nfloors+1:3*Nfloors)*dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,1:Nfloors)*dif(1+count(axpos_index):Nfloors+count(axpos_index),M3_col_no,q))+...
                              dif(2*Nfloors+1+count(axpos_index):3*Nfloors+count(axpos_index),M2_col_no,q)'*(Cov_Tot_F(2*Nfloors+1:3*Nfloors,Nfloors+1:2*Nfloors)*dif(Nfloors+1+count(axpos_index):2*Nfloors+count(axpos_index),M3_col_no,q));           
                end

                P_mean    = WL_fact*dif([count(axpos_index)+1:count(axpos_index+1)], P_col_no,q)'* Fls_mean;
                M2_mean   = WL_fact*dif([count(axpos_index)+1:count(axpos_index+1)], M2_col_no,q)'* Fls_mean;
                M3_mean   = WL_fact*dif([count(axpos_index)+1:count(axpos_index+1)], M3_col_no,q)'* Fls_mean;
                
                P_satic   = DL_fact*(P_DL(q,axpos_index)  + P_SDL(q,axpos_index))  + LL_fact*P_LL(q,axpos_index);
                M2_satic  = DL_fact*(M2_DL(q,axpos_index) + M2_SDL(q,axpos_index)) + LL_fact*M2_LL(q,axpos_index);
                M3_satic  = DL_fact*(M3_DL(q,axpos_index) + M3_SDL(q,axpos_index)) + LL_fact*M3_LL(q,axpos_index);
                
                % ----------------------------------
                % AISC equations (H1-1a) and (H1-1b)
                % ----------------------------------
                
                if ((P_mean+P_satic+g*sqrt(C_NN))>=0)  &  ((P_mean+P_satic-g*sqrt(C_NN))>=0)

                    if (abs((P_mean+P_satic)+g*sqrt(C_NN))/(0.9*Pnt(q)) < 0.2) & (abs((P_mean+P_satic)-g*sqrt(C_NN))/(0.9*Pnt(q)) < 0.2) 
                        Bij_peak_1(1,axpos_index)=(abs(P_mean+P_satic)/(2*0.9*Pnt(q))) + (abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q)))+...
                                                   WL_fact*g*sqrt(((2*0.9*Pnt(q))^-2)*C_NN + ((0.9*Mn2(q))^-2)*C_M2M2 + ((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*((2*0.9*Pnt(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*((2*0.9*Pnt(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);

                        Bij_peak_2(1,axpos_index)=0; 

                    elseif (abs((P_mean+P_satic)+g*sqrt(C_NN))/(0.9*Pnt(q)) >= 0.2) & (abs((P_mean+P_satic)-g*sqrt(C_NN))/(0.9*Pnt(q)) >= 0.2) 
                        Bij_peak_1(1,axpos_index)=0;

                        Bij_peak_2(1,axpos_index)=(abs(P_mean+P_satic)/(0.9*Pnt(q))) + (8/9)*((abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q))))+...
                                                   WL_fact*g*sqrt(((0.9*Pnt(q))^-2)*C_NN + ((8/9)^2)*((0.9*Mn2(q))^-2)*C_M2M2 + ((8/9)^2)*((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*(8/9)*((0.9*Pnt(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*(8/9)*((0.9*Pnt(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((8/9)^2)*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);

                    else
                        Bij_peak_1(1,axpos_index)=(abs(P_mean+P_satic)/(2*0.9*Pnt(q))) + (abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q)))+...
                                                   WL_fact*g*sqrt(((2*0.9*Pnt(q))^-2)*C_NN + ((0.9*Mn2(q))^-2)*C_M2M2 + ((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*((2*0.9*Pnt(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*((2*0.9*Pnt(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);

                        Bij_peak_2(1,axpos_index)=(abs(P_mean+P_satic)/(0.9*Pnt(q))) + (8/9)*((abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q))))+...
                                                   WL_fact*g*sqrt(((0.9*Pnt(q))^-2)*C_NN + ((8/9)^2)*((0.9*Mn2(q))^-2)*C_M2M2 + ((8/9)^2)*((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*(8/9)*((0.9*Pnt(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*(8/9)*((0.9*Pnt(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((8/9)^2)*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);
                    end
                
                elseif ((P_mean+P_satic+g*sqrt(C_NN))<0)  &  ((P_mean+P_satic-g*sqrt(C_NN))<0)

                    if (abs((P_mean+P_satic)+g*sqrt(C_NN))/(0.9*Pnc(q)) < 0.2) & (abs((P_mean+P_satic)-g*sqrt(C_NN))/(0.9*Pnc(q)) < 0.2) 
                        Bij_peak_1(1,axpos_index)=(abs(P_mean+P_satic)/(2*0.9*Pnc(q))) + (abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q)))+...
                                                   WL_fact*g*sqrt(((2*0.9*Pnc(q))^-2)*C_NN + ((0.9*Mn2(q))^-2)*C_M2M2 + ((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*((2*0.9*Pnc(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*((2*0.9*Pnc(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);

                        Bij_peak_2(1,axpos_index)=0; 

                    elseif (abs((P_mean+P_satic)+g*sqrt(C_NN))/(0.9*Pnc(q)) >= 0.2) & (abs((P_mean+P_satic)-g*sqrt(C_NN))/(0.9*Pnc(q)) >= 0.2) 
                        Bij_peak_1(1,axpos_index)=0;

                        Bij_peak_2(1,axpos_index)=(abs(P_mean+P_satic)/(0.9*Pnc(q))) + (8/9)*((abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q))))+...
                                                   WL_fact*g*sqrt(((0.9*Pnc(q))^-2)*C_NN + ((8/9)^2)*((0.9*Mn2(q))^-2)*C_M2M2 + ((8/9)^2)*((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*(8/9)*((0.9*Pnc(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*(8/9)*((0.9*Pnc(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((8/9)^2)*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);

                    else
                        Bij_peak_1(1,axpos_index)=(abs(P_mean+P_satic)/(2*0.9*Pnc(q))) + (abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q)))+...
                                                   WL_fact*g*sqrt(((2*0.9*Pnc(q))^-2)*C_NN + ((0.9*Mn2(q))^-2)*C_M2M2 + ((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*((2*0.9*Pnc(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*((2*0.9*Pnc(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);

                        Bij_peak_2(1,axpos_index)=(abs(P_mean+P_satic)/(0.9*Pnc(q))) + (8/9)*((abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q))))+...
                                                   WL_fact*g*sqrt(((0.9*Pnc(q))^-2)*C_NN + ((8/9)^2)*((0.9*Mn2(q))^-2)*C_M2M2 + ((8/9)^2)*((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*(8/9)*((0.9*Pnc(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*(8/9)*((0.9*Pnc(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((8/9)^2)*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);
                    end                    
                                      
                else

                    if (abs((P_mean+P_satic)+g*sqrt(C_NN))/(0.9*Pnc(q)) < 0.2) & (abs((P_mean+P_satic)-g*sqrt(C_NN))/(0.9*Pnc(q)) < 0.2) 
                        Bij_peak_1(1,axpos_index)=(abs(P_mean+P_satic)/(2*0.9*Pnc(q))) + (abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q)))+...
                                                   WL_fact*g*sqrt(((2*0.9*Pnc(q))^-2)*C_NN + ((0.9*Mn2(q))^-2)*C_M2M2 + ((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*((2*0.9*Pnc(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*((2*0.9*Pnc(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);

                        Bij_peak_2(1,axpos_index)=0; 

                    elseif (abs((P_mean+P_satic)+g*sqrt(C_NN))/(0.9*Pnc(q)) >= 0.2) & (abs((P_mean+P_satic)-g*sqrt(C_NN))/(0.9*Pnc(q)) < 0.2) 
                        
                        Bij_peak_1(1,axpos_index)=(abs(P_mean+P_satic)/(2*0.9*Pnc(q))) + (abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q)))+...
                                                   WL_fact*g*sqrt(((2*0.9*Pnc(q))^-2)*C_NN + ((0.9*Mn2(q))^-2)*C_M2M2 + ((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*((2*0.9*Pnc(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*((2*0.9*Pnc(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);


                        Bij_peak_2(1,axpos_index)=(abs(P_mean+P_satic)/(0.9*Pnt(q))) + (8/9)*((abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q))))+...
                                                   WL_fact*g*sqrt(((0.9*Pnt(q))^-2)*C_NN + ((8/9)^2)*((0.9*Mn2(q))^-2)*C_M2M2 + ((8/9)^2)*((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*(8/9)*((0.9*Pnt(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*(8/9)*((0.9*Pnt(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((8/9)^2)*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);

                    else
                        Bij_peak_1(1,axpos_index)=(abs(P_mean+P_satic)/(2*0.9*Pnc(q))) + (abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q)))+...
                                                   WL_fact*g*sqrt(((2*0.9*Pnc(q))^-2)*C_NN + ((0.9*Mn2(q))^-2)*C_M2M2 + ((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*((2*0.9*Pnc(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*((2*0.9*Pnc(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);

                        Bij_peak_2(1,axpos_index)=(abs(P_mean+P_satic)/(0.9*Pnc(q))) + (8/9)*((abs(M2_mean+M2_satic)/(0.9*Mn2(q))) + (abs(M3_mean+M3_satic)/(0.9*Mn3(q))))+...
                                                   WL_fact*g*sqrt(((0.9*Pnc(q))^-2)*C_NN + ((8/9)^2)*((0.9*Mn2(q))^-2)*C_M2M2 + ((8/9)^2)*((0.9*Mn3(q))^-2)*C_M3M3+...
                                                                  2*(8/9)*((0.9*Pnc(q)*0.9*Mn2(q))^-1)*C_NM2 + 2*(8/9)*((0.9*Pnc(q)*0.9*Mn3(q))^-1)*C_NM3 + 2*((8/9)^2)*((0.9*Mn2(q)*0.9*Mn3(q))^-1)*C_M2M3);
                    end

                end
               
                Bij_peak_3sec(1,axpos_index)=max(Bij_peak_1(1,axpos_index),Bij_peak_2(1,axpos_index)); 
                
                %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                    
            end  % loop on member axial position index (axpos_index)

            Bij_peak=max(Bij_peak_3sec);
            Bij_RS(a,b,q)=Bij_peak;
            
        end   % loop on member (q)
        %toc
        %t_members=toc
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        c           = c+1;
        counter     = c/(length(WD)*length(WS));
        waitbar(counter,w);
    end   % loop on WS
end   % loop on WD
close(w)
%toc
%t_WD_WS=toc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% SAVE PEAK WIND EFFECTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Save files contining peak wind effects using 'flnSaveRsBij', 'flnSaveRsInDr' and 'flnSaveRsAcc'.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

K1 = findstr(flnSaveRsBij,'.mat');
if ~isempty(K1)
    flnSaveRsBij = flnSaveRsBij(1:K1-1);
end
save ([flnSaveRsBij],'Bij_RS');

for j=1:sets
    K2 = findstr(flnSaveRsInDr,'.mat');
    if ~isempty(K2)
        flnSaveRsInDr = flnSaveRsInDr(1:K2-1);
    end
    save ([flnSaveRsInDr '_set_' num2str(j)],['InDr_RS_set_' num2str(j)]);
end

for j=1:acc_points
    K3 = findstr(flnSaveRsAcc,'.mat');
    if ~isempty(K3)
        flnSaveRsAcc = flnSaveRsAcc(1:K3-1);
    end
    save ([flnSaveRsAcc '_point_' num2str(j)],['Acc_RS_point_' num2str(j)]);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%