function Program2;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Program2.m %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Calculates the mean-recurrence intervals (MRI) of wind effects for each member

global  textA  axesA_text  textB  axesB_text  input_coords  pos_on  pos_off  fig  sets  acc_points 
% 1. Building Information
global  Nfloors   Fdofs  Ndofs   RNmodes  AnL_A  AnL_B  anal  H_bldg
global  T  T_str  D  D_str  flnMode_shape  evectors  omega  h  
% 2. Wind Tunnel Information
global  flnFl  Vm  freq  ms  Npoints  Nstart 
% 3. Program Inputs
global  flnMem  flnDif  flnProps  mem_list  props  WS  WS_str  WD  WD_str
global  MRIBij  MRIBij_str  MRIDrAc  MRIDrAc_str  mri  IMdir_A  IMdir_B  intmeth  mem_out
% 4. Loads and Reactions
global  flnMass  DL  SDL  LL  g
global  flnDLr  flnSDLr  flnLLr  frames_DL  frames_SDL  frames_LL 
global  DLf  SDLf  LLf  WLf
% 5. Wind Effect Selection
global  Qss  Hmp  Hfile  flHfile  Vth  Npointsout
global  Qs flnInDr flnAcc 
% 6. Calculations
global  flnSaveRsBij  flnSaveRsInDr  flnSaveRsAcc  flnSaveBijMRI  flnSaveInDrMRI  flnSaveAccMRI
% 7. Calculations MRI's
global  AnL_A  AnL_B  IMdir_A  IMdir_B  Hmp  Vth  DLf  SDLf  LLf  WLf
global  mem_out  mem_list
% 8. Save/Load Data
global  fnSAVE  flSAVE  flnSAVE  fnLOAD  flLOAD  flnLOAD

%%%%%%%%%%%%%%%%%%%%%%%% Member list : mem_list, Page 3, [1 x any] %%%%%%%%%%%%%%%%%%%%%%%%%%%

w = waitbar(0,'Member MRI calculation   Please wait...'); c=0;fighan=w;

%%%%%%%%%%%%%%%%%%%%%%%% Member list : mem_list, Page 3, [1 x any] %%%%%%%%%%%%%%%%%%%%%%%%%%%
% Loop through each member; load the saved Gaussian distributed estimated maximum, peak wind
% effect matrix; map each wind speed in the hurricane database to a peak wind effect from
% each matrix; calculate the mean recurrence interval
load ([flnSaveRsBij]);
[V_lookup,dir_lookup,nhurr,recurrence] = HurrData;
for p=1:length(mem_list(1,:))
    max_Bij_est(:,:)=Bij_RS(:,:,p); 
        for a=1:nhurr
            for b=1:size(V_lookup,2)
                if V_lookup(a,b) > Vth             % Impose minimum threshold of wind speeds, Vth
                    V_kept(a,b)=V_lookup(a,b);
                    if IMdir_A == 1                % Interpolation Method A: between WS and WD
                        if length(WD)==1
                            Bij_Emax_lookup(a,b) = interp1(WS,max_Bij_est,V_kept(a,b));
                        else
                            Bij_Emax_lookup(a,b) = interp2(WS,WD,max_Bij_est,V_kept(a,b),dir_lookup(b));
                        end
                    elseif IMdir_B == 1           % Interpolation Method B: between WS, larger WD
                            for u=1:size(max_Bij_est,1)
                                Bij_Emax_V(u)        = interp1(WS,max_Bij_est(u,:),V_kept(a,b));
                            end
                            D_index                  = 1:size(max_Bij_est,1);   % 1:36 to match table directions
                            D_V_index = interp1(WD,D_index,dir_lookup(b));
                            Bij_Emax_lookup(a,b) = max(Bij_Emax_V(floor(D_V_index)),Bij_Emax_V(ceil(D_V_index)));
                    end     % loop on method 1 or 2
                else
                    V_kept(a,b)=0;
                    Bij_Emax_lookup(a,b)     = 0;
                end               % loop V_lookup > Vth
            end                 % loop on 'b'
            % Max Bij for each event (999 in total)
            Bij_Est_max_event(a)         = max(Bij_Emax_lookup(a,:));
        end                   % loop on 'a' 
        % Rank order the vector to prepare for MRI calculation
        sorted_Bij_Est_max_mat(:,1)      = -sort( -Bij_Est_max_event );
        for i = 1:length(MRIBij)
            rank                   = 999 / recurrence / MRIBij(i);
            Bij_MRIs(i,p)  = interp1(sorted_Bij_Est_max_mat(:,1), rank);
        end
    c=c+1;
    counter=c/( length(mem_list(1,:)) ); 
    waitbar(counter,fighan);
end     % loop on member
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% SAVE MRI FOR EACH MEMBER %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Save the sorted vectors and all associated MRI's for each member using 'flnSaveBijMRI'
K3 = findstr(flnSaveBijMRI,'.mat');
if ~isempty(K3)
    flnSaveBijMRI = flnSaveBijMRI(1:K3-1);
end
save ([flnSaveBijMRI],'Bij_MRIs');
close(fighan)

%%%%%%%%%%%%%%% Interstory drift : interstory_location , Page 5, [any x 3] %%%%%%%%%%%%%%%%%%%

w = waitbar(0,'Inter-story drift MRI calculation   Please wait...'); c=0;fighan=w;

%%%%%%%%%%%%%%% Interstory drift : interstory_location , Page 5, [any x 3] %%%%%%%%%%%%%%%%%%%
% Loop through each Interstory drift constraint; load the saved absolute observed or estimated 
% maximum, peak wind effect matrix; map each wind speed in the hurricane database to a peak 
% wind effect from each matrix; calculate the mean recurrence interval


for j=1:sets    
    load ([flnSaveRsInDr '_set_' num2str(j)]);
    
    [V_lookup,dir_lookup,nhurr,recurrence] = HurrData;
    
    for p=1:Nfloors
         
        eval(['Max_Drift_x = InDr_RS_set_' num2str(j) '(:,:,p);']);
        eval(['Max_Drift_y = InDr_RS_set_' num2str(j) '(:,:,p+Nfloors);']);
        
            for a=1:nhurr
                for b=1:size(V_lookup,2)
                    if V_lookup(a,b) > Vth             % Impose minimum threshold of wind speeds, Vth
                        V_kept(a,b)=V_lookup(a,b);
                        if IMdir_A == 1                % Interpolation Method A: between WS and WD
                            if length(WD)==1
                                Drift_x_Max_lookup(a,b) = interp1(WS,Max_Drift_x,V_kept(a,b));
                                Drift_y_Max_lookup(a,b) = interp1(WS,Max_Drift_y,V_kept(a,b));
                            else
                                Drift_x_Max_lookup(a,b) = interp2(WS,WD,Max_Drift_x,V_kept(a,b),dir_lookup(b));
                                Drift_y_Max_lookup(a,b) = interp2(WS,WD,Max_Drift_y,V_kept(a,b),dir_lookup(b));
                            end
                        elseif IMdir_B == 1           % Interpolation Method B: between WS, larger WD
                                for u=1:size(max_Bij_est,1)
                                    Drift_x_Max_V(u)        = interp1(WS,Max_Drift_x(u,:),V_kept(a,b));
                                    Drift_y_Max_V(u)        = interp1(WS,Max_Drift_y(u,:),V_kept(a,b));  
                                end
                                D_index                  = 1:size(max_Bij_est,1);   % 1:36 to match table directions
                                D_V_index = interp1(WD,D_index,dir_lookup(b));
                                Drift_x_Max_lookup(a,b) = max(Drift_x_Max_V(floor(D_V_index)),Drift_x_Max_V(ceil(D_V_index)));
                                Drift_y_Max_lookup(a,b) = max(Drift_y_Max_V(floor(D_V_index)),Drift_y_Max_V(ceil(D_V_index)));
                        end     % loop on method 1 or 2
                    else
                        V_kept(a,b)=0;
                        Drift_x_Max_lookup(a,b)     = 0;
                        Drift_y_Max_lookup(a,b)     = 0;
                    end               % loop V_lookup > Vth
                end                 % loop on 'b'
                % Max Bij for each event (999 in total)
                Drift_x_Max_event(a)         = max(Drift_x_Max_lookup(a,:));
                Drift_y_Max_event(a)         = max(Drift_y_Max_lookup(a,:));
            end                   % loop on 'a' 
            % Rank order the vector to prepare for MRI calculation
            sorted_Drift_x_Max_mat(:,1)      = -sort( -Drift_x_Max_event );
            sorted_Drift_y_Max_mat(:,1)      = -sort( -Drift_y_Max_event );
            for i = 1:length(MRIDrAc)
                rank                = 999 / recurrence / MRIDrAc(i);
                InDr_MRIs(p,1,i)  = interp1(sorted_Drift_x_Max_mat(:,1), rank);
                InDr_MRIs(p,2,i)  = interp1(sorted_Drift_y_Max_mat(:,1), rank);
            end
    end     % loop on constrint
    eval ([ 'InDr_MRIs_set_' num2str(j) '(:,:,:) = InDr_MRIs; ']);
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% SAVE MRI FOR EACH CONSTRAINT %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Save the sorted vectors and all associated MRI's for each constrint using 'flnSaveInDrMRI'
    K4 = findstr(flnSaveInDrMRI,'.mat');
    if ~isempty(K4)
        flnSaveInDrMRI = flnSaveInDrMRI(1:K4-1);
    end
    save ([flnSaveInDrMRI '_set_' num2str(j)],['InDr_MRIs_set_',num2str(j)]);
    
    c=c+1;
    counter=c/( sets  );
    waitbar(counter,fighan);
end
close(fighan)

%%%%%%%%%%% Top floor acceleration : acceleration_location , Page 5, [any x 2] %%%%%%%%%%%%%%%
                                            
w = waitbar(0,'Acceleration MRI calculation    Please wait...'); c=0;fighan=w;

%%%%%%%%%%% Top floor acceleration : acceleration_location , Page 5, [any x 2] %%%%%%%%%%%%%%%
% Loop through each Interstory drift constraint; load the saved absolute observed or estimated 
% maximum, peak wind effect matrix; map each wind speed in the hurricane database to a peak 
% wind effect from each matrix; calculate the mean recurrence interval

for j=1:acc_points
    
    load ([flnSaveRsAcc '_point_' num2str(j)]);
    [V_lookup,dir_lookup,nhurr,recurrence] = HurrData;
         
    eval(['Max_Acc_x = Acc_RS_point_' num2str(j) '(:,:,1);']);
    eval(['Max_Acc_y = Acc_RS_point_' num2str(j) '(:,:,2);']);


    for a=1:nhurr
        for b=1:size(V_lookup,2)
            if V_lookup(a,b) > Vth             % Impose minimum threshold of wind speeds, Vth
                V_kept(a,b)=V_lookup(a,b);
                if IMdir_A == 1                % Interpolation Method A: between WS and WD
                    if length(WD)==1
                        Acc_x_Max_lookup(a,b) = interp1(WS,Max_Acc_x,V_kept(a,b));
                        Acc_y_Max_lookup(a,b) = interp1(WS,Max_Acc_y,V_kept(a,b));
                    else
                        Acc_x_Max_lookup(a,b) = interp2(WS,WD,Max_Acc_x,V_kept(a,b),dir_lookup(b));
                        Acc_y_Max_lookup(a,b) = interp2(WS,WD,Max_Acc_y,V_kept(a,b),dir_lookup(b));
                    end
                elseif IMdir_B == 1           % Interpolation Method B: between WS, larger WD
                        for u=1:size(max_Bij_est,1)
                            Acc_x_Max_V(u)        = interp1(WS,Max_Acc_x(u,:),V_kept(a,b));
                            Acc_y_Max_V(u)        = interp1(WS,Max_Acc_y(u,:),V_kept(a,b));  
                        end
                        D_index                  = 1:size(max_Bij_est,1);   % 1:36 to match table directions
                        D_V_index = interp1(WD,D_index,dir_lookup(b));
                        Acc_x_Max_lookup(a,b) = max(Acc_x_Max_V(floor(D_V_index)),Acc_x_Max_V(ceil(D_V_index)));
                        Acc_y_Max_lookup(a,b) = max(Acc_y_Max_V(floor(D_V_index)),Acc_y_Max_V(ceil(D_V_index)));
                end     % loop on method 1 or 2
            else
                V_kept(a,b)=0;
                Acc_x_Max_lookup(a,b)     = 0;
                Acc_y_Max_lookup(a,b)     = 0;
            end               % loop V_lookup > Vth
        end                 % loop on 'b'
        % Max Bij for each event (999 in total)
        Acc_x_Max_event(a)         = max(Acc_x_Max_lookup(a,:));
        Acc_y_Max_event(a)         = max(Acc_y_Max_lookup(a,:));
    end                   % loop on 'a' 
    % Rank order the vector to prepare for MRI calculation
    sorted_Acc_x_Max_mat(:,1)      = -sort( -Acc_x_Max_event );
    sorted_Acc_y_Max_mat(:,1)      = -sort( -Acc_y_Max_event );
    for i = 1:length(MRIDrAc)
        rank                = 999 / recurrence / MRIDrAc(i);
        Acc_MRIs(1,1,i)  = interp1(sorted_Acc_x_Max_mat(:,1), rank);
        Acc_MRIs(1,2,i)  = interp1(sorted_Acc_y_Max_mat(:,1), rank);
    end
    eval ([ 'Acc_MRIs_point_' num2str(j) '(:,:,:) = Acc_MRIs; ']);
         
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% SAVE MRI FOR EACH CONSTRAINT %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Save the sorted vectors and all associated MRI's for each constrint using 'flnSaveAccMRI'
    K5 = findstr(flnSaveAccMRI,'.mat');
    if ~isempty(K5)
        flnSaveAccMRI = flnSaveAccMRI(1:K5-1);
    end
    save ([flnSaveAccMRI '_point_' num2str(j)],['Acc_MRIs_point_',num2str(j)]);
    
    c=c+1;
    counter=c/( acc_points  );
    waitbar(counter,fighan);
end
close(fighan)